@@ -28,4 +28,11 @@ TRAITS = [
     # not make sense to use in GET /allocation_candidates until/unless there is
     # a way to tie it to the condition of SAME_HOST-ness.
     'SAME_HOST_COLD_MIGRATE',
+    # The virt driver supports rescuing boot from volume instances.
+    'RESCUE_BFV',
+    # The compute manager supports handling accelerator requests.
+    'ACCELERATORS',
+    # The compute manager supports the `socket` value for the
+    # hw_pci_numa_affinity_policy image property/flavor extra spec.
+    'SOCKET_PCI_NUMA_AFFINITY',
 ]
